@@ -14,7 +14,7 @@ from importlib.metadata import version, PackageNotFoundError
 
 import click
 
-from outdated import warn_if_outdated
+from outdated import check_outdated
 
 from .main import TgWrap
 
@@ -24,7 +24,23 @@ try:
 except PackageNotFoundError:
     __version__ = '0.0.0'
 
-warn_if_outdated(PACKAGE_NAME, __version__)
+def check_latest_version():
+    """ check for later versions on pypi """
+    try:
+        is_outdated, latest_version = check_outdated(PACKAGE_NAME, __version__)
+        if is_outdated:
+            click.secho(
+                f'Your local version ({__version__}) is out of date! Latest is {latest_version}!',
+                bold=True, file=sys.stderr,
+            )
+    except ValueError:
+        # this happens when your local version is ahead of the pypi version,
+        # which happens only in development
+        pass
+    except KeyError:
+        # this happens when in dev mode, message could be removed
+        click.secho('Could not determine package version, continue nevertheless.', file=sys.stderr)
+        pass
 
 CLICK_CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 
@@ -122,6 +138,8 @@ def run(command, verbose, debug, dry_run, no_lock, update_source,
     auto_approve, working_dir, terragrunt_args):
     """ [default] Executes a terragrunt command on a single project """
 
+    check_latest_version()
+
     tgwrap = TgWrap(verbose=verbose)
     tgwrap.run(
         command=command,
@@ -179,6 +197,8 @@ def run_all(command, verbose, debug, dry_run, no_lock, update_source, exclude_ex
     step_by_step, working_dir, terragrunt_args):
     """ Executes a terragrunt command across multiple projects """
 
+    check_latest_version()
+
     tgwrap = TgWrap(verbose=verbose)
     tgwrap.run_all(
         command=command,
@@ -227,6 +247,8 @@ def run_all(command, verbose, debug, dry_run, no_lock, update_source, exclude_ex
 def run_import(address, id, verbose, dry_run, working_dir, no_lock, terragrunt_args):
     """ Executes the terragrunt/terraform import command """
 
+    check_latest_version()
+
     tgwrap = TgWrap(verbose=verbose)
     tgwrap.run_import(
         address=address,
@@ -264,6 +286,8 @@ def run_import(address, id, verbose, dry_run, working_dir, no_lock, terragrunt_a
 def analyze(verbose, dry_run, exclude_external_dependencies, working_dir, terragrunt_args):
     """ Analyzes the plan files """
 
+    check_latest_version()
+
     tgwrap = TgWrap(verbose=verbose)
     tgwrap.analyze(
         dry_run=dry_run,
@@ -320,6 +344,8 @@ def analyze(verbose, dry_run, exclude_external_dependencies, working_dir, terrag
 def deploy(source_domain, source_stage, target_domain, target_stage, verbose, dry_run, clean_up, include_lock_file, working_dir):
     """ Deploys the terragrunt config files from one stage to another (and possibly to a different domain) """
 
+    check_latest_version()
+
     tgwrap = TgWrap(verbose=verbose)
     tgwrap.deploy(
         source_domain=source_domain,
