@@ -17,9 +17,9 @@ import sys
 import subprocess
 import shlex
 import shutil
-import random
 import string
 import re
+import tempfile
 import json
 import click
 import networkx as nx
@@ -72,9 +72,6 @@ class TgWrap():
     def __init__(self, verbose):
         self.printer = Printer(verbose)
 
-        self.run_id = self.generate_random_string()
-        self.printer.verbose(f"Run id: {self.run_id}")
-
         # Check if the "TERRAGRUNT_SOURCE" environment variable is set
         env_var = "TERRAGRUNT_SOURCE"
         if env_var in os.environ:
@@ -90,9 +87,6 @@ class TgWrap():
         """ Checks if a program is installed on the system """
         return shutil.which(program) is not None
 
-    def generate_random_string(self, length=8):
-        return ''.join(random.choices(string.ascii_lowercase + string.digits, k=length))
-
     def prepare_groups(self, graph, exclude_external_dependencies):
         """ Prepare the list of groups that will be executed """
         groups = []
@@ -123,23 +117,28 @@ class TgWrap():
         """ Gets the directed graph of terragrunt dependencies, and parse it into a graph object """
         graph = None
         try:
-            temp_file = f'{os.environ["TMPDIR"]}tg-dependencies-{self.run_id}.gv'
-            with open(temp_file, 'w', encoding='utf8') as f:
-                working_dir_stmt = f'--terragrunt-working-dir {working_dir}' if working_dir else ''
-                command = \
-                    f'terragrunt graph-dependencies --terragrunt-non-interactive {working_dir_stmt}'
-                rc = subprocess.run(
-                    shlex.split(command),
-                    text=True,
-                    stdout=f,
-                )
-                self.printer.verbose(rc)
+            f = tempfile.NamedTemporaryFile(mode='w+', prefix='tgwrap-', delete=True)
+            self.printer.verbose(f"Opened temp file for graph collection: {f.name}")
+
+            working_dir_stmt = f'--terragrunt-working-dir {working_dir}' if working_dir else ''
+            command = \
+                f'terragrunt graph-dependencies --terragrunt-non-interactive {working_dir_stmt}'
+            rc = subprocess.run(
+                shlex.split(command),
+                text=True,
+                stdout=f,
+            )
+            self.printer.verbose(rc)
+
+            f.flush()
 
             # Read the directed graph and reverse it
-            graph = nx.DiGraph(nx.nx_pydot.read_dot(temp_file)).reverse()
+            graph = nx.DiGraph(nx.nx_pydot.read_dot(f.name)).reverse()
         except Exception as e:
             self.printer.error(e)
             raise click.ClickException(e)
+        finally:
+            f.close()
 
         return graph
 
@@ -159,7 +158,7 @@ class TgWrap():
         if ask_for_confirmation or self.printer.verbose:
             self.printer.header("The following groups will be processed:")
             for idx, group in enumerate(groups):
-                self.printer.normal(f"\nGroup {idx}:")
+                self.printer.normal(f"\nGroup {idx+1}:")
                 for directory in group:
                     self.printer.normal(f"- {directory}")
 
@@ -170,7 +169,7 @@ class TgWrap():
 
         stop_processing = False
         for idx, group in enumerate(groups):
-            self.printer.header(f'Group {idx}')
+            self.printer.header(f'Group {idx+1}')
             self.printer.normal(group)
 
             if command:
@@ -191,21 +190,26 @@ class TgWrap():
                             if collect_output_file:
                                 collect_output_file.write(f'{directory}{self.SEPARATOR}')
                                 collect_output_file.flush()
-                            temp_file = f'{os.environ["TMPDIR"]}tgwrap-error-{self.run_id}'
-                            messages = ""
-                            with open(temp_file, 'w', encoding='utf8') as f:
-                                rc = {'returncode': 0}
-                                rc = subprocess.run(
-                                    shlex.split(command),
-                                    text=True,
-                                    cwd=directory,
-                                    stdout=collect_output_file if collect_output_file else sys.stdout,
-                                    stderr=f,
-                                )
-                                self.printer.verbose(rc)
 
-                            with open(temp_file, 'r', encoding='utf8') as f:
-                                messages = f.read()
+                            messages = ""
+
+                            f = tempfile.NamedTemporaryFile(mode='w+', prefix='tgwrap-', delete=True)
+                            self.printer.verbose(f"Opened temp file for error collection: {f.name}")
+
+                            rc = {'returncode': 0}
+                            rc = subprocess.run(
+                                shlex.split(command),
+                                text=True,
+                                cwd=directory,
+                                stdout=collect_output_file if collect_output_file else sys.stdout,
+                                stderr=f,
+                            )
+                            self.printer.verbose(rc)
+
+                            f.flush()
+
+                            messages = f.read()
+
                             if rc.returncode != 0 or 'error' in messages.lower():
                                 raise Exception(
                                     'An error situation detected while processing the terragrunt graph.'
@@ -219,6 +223,8 @@ class TgWrap():
 
                             stop_processing = True
                             break
+                        finally:
+                            f.close()
 
             if stop_processing:
                 break
@@ -401,82 +407,89 @@ class TgWrap():
             terragrunt_args=terragrunt_args,
             )
 
-        # then run it and capture the output
-        temp_file = f'{os.environ["TMPDIR"]}tgwrap-show-{self.run_id}'
-        json_file = f'{os.environ["TMPDIR"]}planfile-{self.run_id}.json'
-        with open(temp_file, 'w', encoding='utf8') as f:
-            self.run_di_graph(
-                command=cmd,
-                exclude_external_dependencies=exclude_external_dependencies,
-                dry_run=dry_run,
-                collect_output_file=f,
-                working_dir=working_dir,
-            )
-
         ts_validation_successful = True
-        with open(temp_file, 'r') as f:
-            for line in f:
-                split_line = line.split(self.SEPARATOR)
-                project = split_line[0]
-                print(project)
-                plan_file = split_line[1]
+        try:
+            # then run it and capture the output
+            with tempfile.NamedTemporaryFile(mode='w+', prefix='tgwrap-', delete=False) as f:
+                self.printer.verbose(f"Opened temp file for output collection: {f.name}")
 
-                self.printer.header(f"Analyse project: {project}")
+                self.run_di_graph(
+                    command=cmd,
+                    exclude_external_dependencies=exclude_external_dependencies,
+                    dry_run=dry_run,
+                    collect_output_file=f,
+                    working_dir=working_dir,
+                )
 
-                try:
-                    d = json.loads(plan_file)
+            with open(f.name, 'r') as f:
+                for line in f:
+                    split_line = line.split(self.SEPARATOR)
+                    project = split_line[0]
+                    plan_file = split_line[1]
 
-                    if 'resource_changes' in d and len(d['resource_changes']) > 0:
-                        self.printer.header('Changes:')
+                    self.printer.header(f"Analyse project: {project}")
 
-                        changes = False
-                        for rc in d['resource_changes']:
-                            # check if we do have actual changes
-                            actions = rc['change']['actions']
-                            if len(actions) == 1 and (actions[0] == 'no-op' or actions[0] == 'read'):
-                                pass # ignore, just an state change
-                            elif 'delete' in actions:
-                                self.printer.warning(f'- {rc["address"]}: {", ".join(actions)}')
-                                changes = True
-                            else:
-                                self.printer.normal(f'- {rc["address"]}: {", ".join(actions)}')
-                                changes = True
+                    try:
+                        d = json.loads(plan_file)
 
-                        if not changes:
-                            print('- no real changes detected.')
+                        if 'resource_changes' in d and len(d['resource_changes']) > 0:
+                            self.printer.header('Changes:')
 
-                    # if so, write to file
-                    with open(json_file, 'w', encoding='utf8') as f:
-                        f.write(plan_file)
+                            changes = False
+                            for rc in d['resource_changes']:
+                                # check if we do have actual changes
+                                actions = rc['change']['actions']
+                                if len(actions) == 1 and (actions[0] == 'no-op' or actions[0] == 'read'):
+                                    pass # ignore, just an state change
+                                elif 'delete' in actions:
+                                    self.printer.warning(f'- {rc["address"]}: {", ".join(actions)}')
+                                    changes = True
+                                else:
+                                    self.printer.normal(f'- {rc["address"]}: {", ".join(actions)}')
+                                    changes = True
 
-                    # Check if the "TERRASAFE_CONFIG" environment variable is set
-                    env_var = "TERRASAFE_CONFIG"
-                    if not env_var in os.environ:
-                        self.printer.warning(
-                            f"{env_var} environment variable is not set, this is required for running the terrasafe command!"
-                            )
-                    else:
-                        self.printer.header(
-                            f"\nRun terrasafe using config {os.environ.get(env_var)}"
-                            )
+                            if not changes:
+                                print('- no real changes detected.')
 
-                        cmd = f"cat {json_file} | terrasafe --config {os.environ.get('TERRASAFE_CONFIG')}"
-                        output = subprocess.run(
-                            cmd,
-                            shell=True,
-                            text=True,
-                            capture_output=True,
-                            )
-                        if output.returncode != 0:
-                            ts_validation_successful = False
-                            self.printer.error(output.stdout)
-                        elif '0 unauthorized' in output.stdout:
-                            self.printer.success(output.stdout)
+                        # if so, write to file
+                        json_file = tempfile.NamedTemporaryFile(mode='w+', prefix='tgwrap-', delete=True)
+                        self.printer.verbose(f"Opened temp file for terrasafe input: {json_file.name}")
 
-                except json.decoder.JSONDecodeError as e:
-                    raise Exception(
-                        f"Planfile for {project} was no proper json, further analysis not possible."
-                        ) from e
+                        json_file.write(plan_file)
+                        json_file.flush
+
+                        # Check if the "TERRASAFE_CONFIG" environment variable is set
+                        env_var = "TERRASAFE_CONFIG"
+                        if not env_var in os.environ:
+                            self.printer.warning(
+                                f"{env_var} environment variable is not set, this is required for running the terrasafe command!"
+                                )
+                        else:
+                            self.printer.header(
+                                f"\nRun terrasafe using config {os.environ.get(env_var)}"
+                                )
+
+                            cmd = f"cat {json_file.name} | terrasafe --config {os.environ.get('TERRASAFE_CONFIG')}"
+                            output = subprocess.run(
+                                cmd,
+                                shell=True,
+                                text=True,
+                                capture_output=True,
+                                )
+                            if output.returncode != 0:
+                                ts_validation_successful = False
+                                self.printer.error(output.stdout)
+                            elif '0 unauthorized' in output.stdout:
+                                self.printer.success(output.stdout)
+
+                    except json.decoder.JSONDecodeError as e:
+                        raise Exception(
+                            f"Planfile for {project} was no proper json, further analysis not possible."
+                            ) from e
+                    finally:
+                        json_file.close()
+        finally:
+            os.remove(f.name)
 
         if not ts_validation_successful:
             raise Exception("Terrasafe validation failed on one or more projects")
